@@ -465,6 +465,7 @@ QString BrowserPage::selectedWords()
     QString text;
     foreach (BrowserWord *word, m_words) {
         if (word->isSelected()) {
+            //qDebug() << "word->text(): " <<  word->text();
             text += word->text();
         }
     }
@@ -498,6 +499,7 @@ void BrowserPage::loadWords()
         if (!qFuzzyCompare(m_wordScaleFactor, m_scaleFactor)) {
             m_wordScaleFactor = m_scaleFactor;
             foreach (BrowserWord *word, m_words) {
+                qDebug() << "1111word->text(): " <<  word->text();
                 word->setScaleFactor(m_scaleFactor);
             }
         }
@@ -889,6 +891,11 @@ QPointF BrowserPage::getTopLeftPos()
     return p;
 }
 
+Dr::FileType BrowserPage::fileType()
+{
+    return m_sheet->fileType();
+}
+
 bool BrowserPage::removeAnnotation(deepin_reader::Annotation *annota)
 {
     if (nullptr == annota)
@@ -1085,6 +1092,18 @@ BrowserAnnotation *BrowserPage::getBrowserAnnotation(const QPointF &point)
     return nullptr;
 }
 
+bool BrowserPage::isExitBookMark(const QPointF &mousePoint)
+{
+    QRect rect(
+        static_cast<int>(bookmarkRect().x()),
+        static_cast<int>(10),
+        39, 39);
+    //qDebug() << "bookmarkMouseRect(): " << bookmarkMouseRect() << "mousePoint" << mousePoint;
+    //qDebug() << "当前鼠标位置是否存在书签: " << bookmarkMouseRect().contains(mousePoint.toPoint());
+    bool flag = bookmarkMouseRect().contains(mousePoint.toPoint());
+    return flag;
+}
+
 BrowserWord *BrowserPage::getBrowserWord(const QPointF &point)
 {
     BrowserWord *item = nullptr;
