@@ -668,6 +668,12 @@ private:
      */
     void showMagnigierImage(const QPoint &point);
 
+    /**
+     * @brief moveScrollBar 移动滚动条
+     * @param point
+     */
+    void moveScrollBar(const QPoint &point);
+
     /**
      * @brief getAnnotPosInPage
      * 将传入的位置拉回到页面里，返回新的位置
