@@ -96,7 +96,7 @@ public:
     Annotation *addIconAnnotation(const QRectF &ponit, const QString &text) override;
 
     Annotation *moveIconAnnotation(Annotation *annot, const QRectF &rect) override;
-    void setPath(const QString &orgPath,const QString& tmpPath);
+    void setPath(const QString &orgPath, const QString &tmpPath, const int &type);
 
 private:
     explicit PDFPage(QMutex *mutex, DPdfPage *page);
@@ -111,6 +111,10 @@ private:
 
     QString m_filePath = "";
     QString m_tmpPath = "";
+    /**
+     * @brief 此属性是为了区分真实的pdf文档及docx转换出来的docx文档
+     */
+    int m_pdfType = 0; //0: pdf  1:docx->pdf
 };
 
 class PDFDocument : public Document
@@ -139,7 +143,7 @@ public:
 
     static PDFDocument *loadDocument(const QString &filePath, const QString &password, deepin_reader::Document::Error &error);
 
-    void setPath(const QString &orgPath,const QString& tmpPath);
+    void setPath(const QString &orgPath, const QString &tmpPath, const int &type);
 private:
     DPdfDoc *m_document = nullptr;
 
@@ -155,6 +159,10 @@ private:
 
     QString m_filePath = "";
     QString m_tmpPath = "";
+    /**
+     * @brief 此属性是为了区分真实的pdf文档及docx转换出来的docx文档
+     */
+    int m_pdfType = 0; //0: pdf  1:docx->pdf
 };
 }
 
