@@ -98,6 +98,19 @@ void SideBarImageListView::handleOpenSuccess()
         for (int index = 0; index < pagesNum; index++)
             pageSrclst << ImagePageInfo_t(index);
         m_imageModel->initModelLst(pageSrclst);
+
+        // 计算Item的大小
+        if (m_imageModel->getModelIndexForPageIndex(0).size() > 0) {
+            qreal pixscale = this->property("adaptScale").toDouble();
+            QModelIndex index = m_imageModel->getModelIndexForPageIndex(0).first();
+            QSize pageSize = index.data(ImageinfoType_e::IMAGE_PAGE_SIZE).toSize();
+            int rotate = index.data(ImageinfoType_e::IMAGE_ROTATE).toInt();
+            if (rotate == 90 || rotate == 270)
+                pageSize = QSize(pageSize.height(), pageSize.width());
+            pageSize.scale(static_cast<int>(174 * pixscale * dApp->devicePixelRatio()), static_cast<int>(174 * pixscale * dApp->devicePixelRatio()), Qt::KeepAspectRatio);
+            const QSize &scalePixSize = pageSize / dApp->devicePixelRatio();
+            setItemSize(QSize(scalePixSize.width(), scalePixSize.height() + 35));
+        }
     } else if (m_listType == E_SideBar::SIDE_BOOKMARK) {
         const QSet<int> &pageList = m_docSheet->getBookMarkList();
         QList<ImagePageInfo_t> pageSrclst;
@@ -244,12 +257,12 @@ int  SideBarImageListView::getPageIndexForModelIndex(int row)
 
 QModelIndex SideBarImageListView::pageUpIndex()
 {
-    qDebug()<< "pageUpIndex() !";
+    qDebug() << "pageUpIndex() !";
     return DListView::moveCursor(QAbstractItemView::MoveUp, Qt::NoModifier);
 }
 
 QModelIndex SideBarImageListView::pageDownIndex()
 {
-    qDebug()<< "pageDownIndex() !";
+    qDebug() << "pageDownIndex() !";
     return DListView::moveCursor(QAbstractItemView::MoveDown, Qt::NoModifier);
 }
