@@ -206,6 +206,7 @@ void Central::handleShortcut(const QString &shortcut)
 bool Central::handleClose(bool needToBeSaved)
 {
     if (nullptr != m_docPage) {
+        qDebug() << __FUNCTION__ << "正在关闭所有 sheet ...";
         return docPage()->closeAllSheets(needToBeSaved);
     }
 
@@ -346,6 +347,7 @@ void Central::dropEvent(QDropEvent *event)
 
             QString filePath = url.toLocalFile();
 
+            qDebug() << "拖动打开文档:" <<  filePath;
             if (!MainWindow::activateSheetIfExist(filePath)) {
                 docPage()->addFileAsync(filePath);
             }
