@@ -91,6 +91,7 @@ DocSheet::DocSheet(const Dr::FileType &fileType, const QString &filePath,  QWidg
     connect(m_renderer, &SheetRenderer::sigOpened, this, &DocSheet::onOpened);
 
     m_browser = new SheetBrowser(this);
+    qDebug() << "新建右侧视图";
     m_browser->setMinimumWidth(DocSheet::BrowserMinWidth);
 
     if (Dr::PDF == fileType)
@@ -119,6 +120,7 @@ DocSheet::DocSheet(const Dr::FileType &fileType, const QString &filePath,  QWidg
 
 DocSheet::~DocSheet()
 {
+    qDebug() << "正在释放当前 sheet ...";
     // 结束正在进行的命令process
     if (nullptr != m_process) {
         __pid_t processid = static_cast<__pid_t>(m_process->processId());
@@ -135,8 +137,15 @@ DocSheet::~DocSheet()
 
     delete m_renderer;
 
+    delete m_searchTask;
+
+    delete m_encryPage;
+
+    delete m_sideAnimation;
+
     if (nullptr != m_tempDir)
         delete m_tempDir;
+    qDebug() << "当前 sheet 已释放";
 }
 
 QImage DocSheet::firstThumbnail(const QString &filePath)
@@ -526,6 +535,7 @@ void DocSheet::copySelectedText()
 
     QClipboard *clipboard = DApplication::clipboard();  //获取系统剪贴板指针
     clipboard->setText(selectedWordsText);
+    qInfo() << "通过ctrl+c将内容复制到剪切板: "/* << selectedWordsText*/;
 }
 
 void DocSheet::highlightSelectedText()
@@ -949,6 +959,7 @@ bool DocSheet::isFullScreen()
 
 void DocSheet::openFullScreen()
 {
+    qDebug() << "打开全屏！";
     CentralDocPage *doc = static_cast<CentralDocPage *>(parent());
     if (nullptr == doc)
         return;
@@ -970,6 +981,7 @@ void DocSheet::openFullScreen()
 
 bool DocSheet::closeFullScreen(bool force)
 {
+    qDebug() << "关闭全屏！";
     CentralDocPage *doc = static_cast<CentralDocPage *>(parent());
     if (nullptr == doc)
         return false;
@@ -1253,6 +1265,7 @@ void DocSheet::onPopPrintDialog()
     preview.setAsynPreview(pageCount());
     preview.setDocName(QFileInfo(filePath()).fileName());
     if (Dr::PDF == fileType() || Dr::DOCX == fileType()) {//旧版本和最新版本使用新接口，PDF文件直接传，解决打印模糊问题
+        qDebug() << "打印预览文件路径: " << openedFilePath();
         preview.setPrintFromPath(openedFilePath());
     }
     connect(&preview, static_cast<void(DPrintPreviewDialog::*)(DPrinter *, const QVector<int> &)>(&DPrintPreviewDialog::paintRequested),
@@ -1279,9 +1292,10 @@ QSizeF DocSheet::pageSizeByIndex(int index)
 
 void DocSheet::resetChildParent()
 {
+    qDebug() << "重置侧边栏的父对象！";
     m_sidebar->setParent(nullptr);
     m_sidebar->setParent(this);
 
-    m_browser->setParent(nullptr);
-    m_browser->setParent(this);
+//    m_browser->setParent(nullptr);
+//    m_browser->setParent(this);
 }
